@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '2.70';
+$CPAN::Perl::Releases::VERSION = '2.72';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -170,8 +170,9 @@ our $data =
 "5.22.2-RC1" => { id => 'SHAY' },
 "5.24.0-RC1" => { id => 'RJBS' },
 "5.24.0-RC2" => { id => 'RJBS' },
-"5.24.0-RC3" => { id => 'RJBS', onlybz2 => 1 },
+"5.24.0-RC3" => { id => 'RJBS' },
 "5.22.2" => { id => 'SHAY' },
+"5.24.0-RC4" => { id => 'RJBS' },
 };
 
 sub perl_tarballs {
@@ -239,7 +240,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 2.70
+version 2.72
 
 =head1 SYNOPSIS
 
